Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(149)

Unified Diff: src/core/SkPMFloat.h

Issue 1047823002: back to Sk4f for SkPMColor (Closed) Base URL: https://skia.googlesource.com/skia@master
Patch Set: rebase Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « bench/PMFloatBench.cpp ('k') | src/effects/SkColorMatrixFilter.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/core/SkPMFloat.h
diff --git a/src/core/SkPMFloat.h b/src/core/SkPMFloat.h
index 27f6f78f26028e47fca9f24ff2908f90faf40f60..31478794580a23898fcde867626a28904590909f 100644
--- a/src/core/SkPMFloat.h
+++ b/src/core/SkPMFloat.h
@@ -34,9 +34,9 @@ public:
#endif
// Freely autoconvert between SkPMFloat and Sk4s.
/*implicit*/ SkPMFloat(const Sk4s& fs) { fColors = fs; }
/*implicit*/ operator Sk4s() const { return fColors; }
float a() const { return fColors[SK_A32_SHIFT / 8]; }
float r() const { return fColors[SK_R32_SHIFT / 8]; }
@@ -65,11 +65,11 @@ public:
}
private:
- Sk4s fColors;
+ Sk4f fColors;
};
#ifdef SKNX_NO_SIMD
// Platform implementations of SkPMFloat assume Sk4s uses SSE or NEON. _none is generic.
#include "../opts/SkPMFloat_none.h"
#else
#if SK_CPU_SSE_LEVEL >= SK_CPU_SSE_LEVEL_SSSE3
@@ -34,9 +34,9 @@ public:
#endif
- // Freely autoconvert between SkPMFloat and Sk4s.
- /*implicit*/ SkPMFloat(const Sk4s& fs) { fColors = fs; }
- /*implicit*/ operator Sk4s() const { return fColors; }
+ // Freely autoconvert between SkPMFloat and Sk4f.
+ /*implicit*/ SkPMFloat(const Sk4f& fs) { fColors = fs; }
+ /*implicit*/ operator Sk4f() const { return fColors; }
float a() const { return fColors[SK_A32_SHIFT / 8]; }
float r() const { return fColors[SK_R32_SHIFT / 8]; }
@@ -65,11 +65,11 @@ public:
};
#ifdef SKNX_NO_SIMD
- // Platform implementations of SkPMFloat assume Sk4s uses SSE or NEON. _none is generic.
+ // Platform implementations of SkPMFloat assume Sk4f uses SSE or NEON. _none is generic.
#include "../opts/SkPMFloat_none.h"
#else
« no previous file with comments | « bench/PMFloatBench.cpp ('k') | src/effects/SkColorMatrixFilter.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698